@@ -175,13 +175,11 @@ import jsii
 import jsii.compat
 import publication
 
+from ._jsii import *
+
 import aws_cdk.aws_ec2
-import aws_cdk.aws_iam
 import aws_cdk.aws_kms
 import aws_cdk.core
-import constructs
-
-from ._jsii import *
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
@@ -193,7 +191,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
     cloudformationResource:
     :cloudformationResource:: AWS::FSx::FileSystem
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, file_system_type: str, subnet_ids: typing.List[str], backup_id: typing.Optional[str]=None, kms_key_id: typing.Optional[str]=None, lustre_configuration: typing.Optional[typing.Union[typing.Optional["LustreConfigurationProperty"], typing.Optional[aws_cdk.core.IResolvable]]]=None, security_group_ids: typing.Optional[typing.List[str]]=None, storage_capacity: typing.Optional[jsii.Number]=None, storage_type: typing.Optional[str]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, windows_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WindowsConfigurationProperty"]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, file_system_type: str, subnet_ids: typing.List[str], backup_id: typing.Optional[str]=None, kms_key_id: typing.Optional[str]=None, lustre_configuration: typing.Optional[typing.Union["LustreConfigurationProperty", aws_cdk.core.IResolvable]]=None, security_group_ids: typing.Optional[typing.List[str]]=None, storage_capacity: typing.Optional[jsii.Number]=None, storage_type: typing.Optional[str]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, windows_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WindowsConfigurationProperty"]]=None) -> None:
         """Create a new ``AWS::FSx::FileSystem``.
 
         :param scope: - scope in which this resource is defined.
@@ -291,7 +289,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "fileSystemType")
 
     @file_system_type.setter
-    def file_system_type(self, value: str):
+    def file_system_type(self, value: str) -> None:
         jsii.set(self, "fileSystemType", value)
 
     @builtins.property
@@ -305,7 +303,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "subnetIds")
 
     @subnet_ids.setter
-    def subnet_ids(self, value: typing.List[str]):
+    def subnet_ids(self, value: typing.List[str]) -> None:
         jsii.set(self, "subnetIds", value)
 
     @builtins.property
@@ -319,7 +317,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "backupId")
 
     @backup_id.setter
-    def backup_id(self, value: typing.Optional[str]):
+    def backup_id(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "backupId", value)
 
     @builtins.property
@@ -333,12 +331,12 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "kmsKeyId")
 
     @kms_key_id.setter
-    def kms_key_id(self, value: typing.Optional[str]):
+    def kms_key_id(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "kmsKeyId", value)
 
     @builtins.property
     @jsii.member(jsii_name="lustreConfiguration")
-    def lustre_configuration(self) -> typing.Optional[typing.Union[typing.Optional["LustreConfigurationProperty"], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def lustre_configuration(self) -> typing.Optional[typing.Union["LustreConfigurationProperty", aws_cdk.core.IResolvable]]:
         """``AWS::FSx::FileSystem.LustreConfiguration``.
 
         see
@@ -347,7 +345,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "lustreConfiguration")
 
     @lustre_configuration.setter
-    def lustre_configuration(self, value: typing.Optional[typing.Union[typing.Optional["LustreConfigurationProperty"], typing.Optional[aws_cdk.core.IResolvable]]]):
+    def lustre_configuration(self, value: typing.Optional[typing.Union["LustreConfigurationProperty", aws_cdk.core.IResolvable]]) -> None:
         jsii.set(self, "lustreConfiguration", value)
 
     @builtins.property
@@ -361,7 +359,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "securityGroupIds")
 
     @security_group_ids.setter
-    def security_group_ids(self, value: typing.Optional[typing.List[str]]):
+    def security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
         jsii.set(self, "securityGroupIds", value)
 
     @builtins.property
@@ -375,7 +373,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "storageCapacity")
 
     @storage_capacity.setter
-    def storage_capacity(self, value: typing.Optional[jsii.Number]):
+    def storage_capacity(self, value: typing.Optional[jsii.Number]) -> None:
         jsii.set(self, "storageCapacity", value)
 
     @builtins.property
@@ -389,12 +387,12 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "storageType")
 
     @storage_type.setter
-    def storage_type(self, value: typing.Optional[str]):
+    def storage_type(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "storageType", value)
 
     @builtins.property
     @jsii.member(jsii_name="windowsConfiguration")
-    def windows_configuration(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WindowsConfigurationProperty"]]]:
+    def windows_configuration(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WindowsConfigurationProperty"]]:
         """``AWS::FSx::FileSystem.WindowsConfiguration``.
 
         see
@@ -403,7 +401,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
         return jsii.get(self, "windowsConfiguration")
 
     @windows_configuration.setter
-    def windows_configuration(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WindowsConfigurationProperty"]]]):
+    def windows_configuration(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WindowsConfigurationProperty"]]) -> None:
         jsii.set(self, "windowsConfiguration", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-fsx.CfnFileSystem.LustreConfigurationProperty", jsii_struct_bases=[], name_mapping={'deployment_type': 'deploymentType', 'export_path': 'exportPath', 'imported_file_chunk_size': 'importedFileChunkSize', 'import_path': 'importPath', 'per_unit_storage_throughput': 'perUnitStorageThroughput', 'weekly_maintenance_start_time': 'weeklyMaintenanceStartTime'})
@@ -582,7 +580,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-fsx.CfnFileSystem.WindowsConfigurationProperty", jsii_struct_bases=[], name_mapping={'active_directory_id': 'activeDirectoryId', 'automatic_backup_retention_days': 'automaticBackupRetentionDays', 'copy_tags_to_backups': 'copyTagsToBackups', 'daily_automatic_backup_start_time': 'dailyAutomaticBackupStartTime', 'deployment_type': 'deploymentType', 'preferred_subnet_id': 'preferredSubnetId', 'self_managed_active_directory_configuration': 'selfManagedActiveDirectoryConfiguration', 'throughput_capacity': 'throughputCapacity', 'weekly_maintenance_start_time': 'weeklyMaintenanceStartTime'})
     class WindowsConfigurationProperty():
-        def __init__(self, *, active_directory_id: typing.Optional[str]=None, automatic_backup_retention_days: typing.Optional[jsii.Number]=None, copy_tags_to_backups: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, daily_automatic_backup_start_time: typing.Optional[str]=None, deployment_type: typing.Optional[str]=None, preferred_subnet_id: typing.Optional[str]=None, self_managed_active_directory_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty"]]]=None, throughput_capacity: typing.Optional[jsii.Number]=None, weekly_maintenance_start_time: typing.Optional[str]=None) -> None:
+        def __init__(self, *, active_directory_id: typing.Optional[str]=None, automatic_backup_retention_days: typing.Optional[jsii.Number]=None, copy_tags_to_backups: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, daily_automatic_backup_start_time: typing.Optional[str]=None, deployment_type: typing.Optional[str]=None, preferred_subnet_id: typing.Optional[str]=None, self_managed_active_directory_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty"]]=None, throughput_capacity: typing.Optional[jsii.Number]=None, weekly_maintenance_start_time: typing.Optional[str]=None) -> None:
             """
             :param active_directory_id: ``CfnFileSystem.WindowsConfigurationProperty.ActiveDirectoryId``.
             :param automatic_backup_retention_days: ``CfnFileSystem.WindowsConfigurationProperty.AutomaticBackupRetentionDays``.
@@ -628,7 +626,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
             return self._values.get('automatic_backup_retention_days')
 
         @builtins.property
-        def copy_tags_to_backups(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def copy_tags_to_backups(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnFileSystem.WindowsConfigurationProperty.CopyTagsToBackups``.
 
             see
@@ -664,7 +662,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
             return self._values.get('preferred_subnet_id')
 
         @builtins.property
-        def self_managed_active_directory_configuration(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty"]]]:
+        def self_managed_active_directory_configuration(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty"]]:
             """``CfnFileSystem.WindowsConfigurationProperty.SelfManagedActiveDirectoryConfiguration``.
 
             see
@@ -703,7 +701,7 @@ class CfnFileSystem(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-fsx.CfnFileSystemProps", jsii_struct_bases=[], name_mapping={'file_system_type': 'fileSystemType', 'subnet_ids': 'subnetIds', 'backup_id': 'backupId', 'kms_key_id': 'kmsKeyId', 'lustre_configuration': 'lustreConfiguration', 'security_group_ids': 'securityGroupIds', 'storage_capacity': 'storageCapacity', 'storage_type': 'storageType', 'tags': 'tags', 'windows_configuration': 'windowsConfiguration'})
 class CfnFileSystemProps():
-    def __init__(self, *, file_system_type: str, subnet_ids: typing.List[str], backup_id: typing.Optional[str]=None, kms_key_id: typing.Optional[str]=None, lustre_configuration: typing.Optional[typing.Union[typing.Optional["CfnFileSystem.LustreConfigurationProperty"], typing.Optional[aws_cdk.core.IResolvable]]]=None, security_group_ids: typing.Optional[typing.List[str]]=None, storage_capacity: typing.Optional[jsii.Number]=None, storage_type: typing.Optional[str]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, windows_configuration: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnFileSystem.WindowsConfigurationProperty"]]]=None) -> None:
+    def __init__(self, *, file_system_type: str, subnet_ids: typing.List[str], backup_id: typing.Optional[str]=None, kms_key_id: typing.Optional[str]=None, lustre_configuration: typing.Optional[typing.Union["CfnFileSystem.LustreConfigurationProperty", aws_cdk.core.IResolvable]]=None, security_group_ids: typing.Optional[typing.List[str]]=None, storage_capacity: typing.Optional[jsii.Number]=None, storage_type: typing.Optional[str]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, windows_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnFileSystem.WindowsConfigurationProperty"]]=None) -> None:
         """Properties for defining a ``AWS::FSx::FileSystem``.
 
         :param file_system_type: ``AWS::FSx::FileSystem.FileSystemType``.
@@ -770,7 +768,7 @@ class CfnFileSystemProps():
         return self._values.get('kms_key_id')
 
     @builtins.property
-    def lustre_configuration(self) -> typing.Optional[typing.Union[typing.Optional["CfnFileSystem.LustreConfigurationProperty"], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def lustre_configuration(self) -> typing.Optional[typing.Union["CfnFileSystem.LustreConfigurationProperty", aws_cdk.core.IResolvable]]:
         """``AWS::FSx::FileSystem.LustreConfiguration``.
 
         see
@@ -815,7 +813,7 @@ class CfnFileSystemProps():
         return self._values.get('tags')
 
     @builtins.property
-    def windows_configuration(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnFileSystem.WindowsConfigurationProperty"]]]:
+    def windows_configuration(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnFileSystem.WindowsConfigurationProperty"]]:
         """``AWS::FSx::FileSystem.WindowsConfiguration``.
 
         see
